@@ -3,9 +3,8 @@
  *                         danny.kukawka@web.de, dkukawka@suse.de          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of version 2 of the GNU General Public License     *
+ *   as published by the Free Software Foundation.                         *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -51,8 +50,8 @@ blacklistEditDialog::blacklistEditDialog( QStringList blacklisted, QString capti
 	
 	changed = initImport;
 	
-	pB_add->setEnabled(FALSE);
-	pB_remove->setEnabled(FALSE);
+	pB_add->setEnabled(false);
+	pB_remove->setEnabled(false);
 	
 	lB_blacklist->insertStringList(blacklist);
 	lB_blacklist->sort();
@@ -110,7 +109,7 @@ void blacklistEditDialog::pB_remove_released(){
 		lB_blacklist->sort();
 		changed = true;
 		
-		pB_remove->setEnabled(FALSE);
+		pB_remove->setEnabled(false);
 		tLabel_info->setText(i18n("Selected entry removed."));
 	}
 	else {
@@ -145,8 +144,8 @@ void blacklistEditDialog::pB_add_released(){
 	
 	// set the widgets back to default
 	lE_blacklist->setText("");
-	pB_remove->setEnabled(FALSE);
-	pB_add->setEnabled(FALSE);
+	pB_remove->setEnabled(false);
+	pB_add->setEnabled(false);
 }
 
 
