@@ -5,9 +5,8 @@
  *                            <dkukawka@suse.de>, <danny.kukawka@web.de>   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of version 2 of the GNU General Public License     *
+ *   as published by the Free Software Foundation.                         *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -32,6 +31,12 @@
 // other QT headers:
 #include <qpixmap.h>
 
+// own headers:
+#include "hardware.h"
+#include "hardware_cpu.h"
+#include "settings.h"
+#include "hardware_batteryCollection.h"
+
 /*! 
 *  \file 	detaileddialog.h
 *  \brief 	Headerfile for detaileddialog.cpp and the class \ref detaileddialog.
@@ -49,7 +54,7 @@ class detaileddialog: public detailed_Dialog {
 
 public:
 	//! default constructor
-	detaileddialog(pDaemon *pdaemon, QPixmap *_pixmap, QWidget *parent = 0, const char *name = 0);
+	detaileddialog(HardwareInfo *_hwinfo, QPixmap *_pixmap, Settings *_set, QWidget *parent = 0, const char *name = 0);
 	//! default destructor
 	~detaileddialog();
 
@@ -58,6 +63,8 @@ private slots:
 	void closeDetailedDlg();
 	//! to setup the battery progress widgets
 	void setBattery();
+	//! to setup the current power consumtion widgets
+	void setPowerConsumption();
 	//! to setup the CPU progress widgets
 	void setProcessor();
 	//! to setup the Throttling CPU progress widgets
@@ -68,8 +75,14 @@ private slots:
 	void setInfos();
 
 private:
-	//! pointer to class pdaemon to get cpu/battey/AC information
-	pDaemon *pd;
+	//! pointer to class HardwareInfo to get cpu/battey/AC information
+	HardwareInfo *hwinfo;
+	//! pointer to class CPUInfo to get CPU information
+	CPUInfo *cpuInfo;
+	//! pointer to hardware information about the primary batteries.
+	BatteryCollection *primaryBatteries;
+	//! pointer to class settinfs to get the current settings
+	Settings *config;
 
 	//! pointer to the kpowersave class
 	QPixmap *pixmap;
