@@ -3,9 +3,8 @@
  *                         danny.kukawka@web.de, dkukawka@suse.de          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of version 2 of the GNU General Public License     *
+ *   as published by the Free Software Foundation.                         *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -73,7 +72,9 @@ infoDialog::infoDialog( KConfig *config, QString captionName, QString message,
 	msgText->setText(message);
 	
 	if (!captionName.isEmpty()) 
-		this->setCaption(captionName);
+		this->setCaption(i18n("KPowersave") + " - " + captionName);
+	else
+		this->setCaption(i18n("KPowersave"));
 
 	if (dontShowAgainMsg.isEmpty()) {
 		dontShowAgain->setHidden(true);
