@@ -5,9 +5,8 @@
 *                            <dkukawka@suse.de>, <danny.kukawka@web.de>   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
+*   it under the terms of version 2 of the GNU General Public License     *
+*   as published by the Free Software Foundation.                         *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -45,11 +44,11 @@
 #include "autosuspend.h"
 #include "configuredialog.h"
 #include "kpowersave_debug.h"
-#include "pdaemon.h"
 #include "screen.h"
 #include "settings.h"
 #include "suspenddialog.h"
 #include "detaileddialog.h"
+#include "hardware.h"
 
 
 /*! 
@@ -73,24 +72,30 @@ private:
 
 	//! to configure kpowersave
 	KConfig *config;	
-	//! KProcess to start YaST-module for configuration of powersave daemon
+	//! KProcess to start YaST-module for configuration
 	KProcess *yast2;
 	//! KProcess to send commands to xscreensaver
 	KProcess *xscreensaver;
 	//! instance of \ref ConfigureDialog
 	/*! the implemtation and all related functions for the configure dialog*/
 	ConfigureDialog *configDlg;
-	//! instance of \ref pDaemon
-	pDaemon *pdaemon;
 	//! instance of \ref screen
-	screen *new_screen;
+	screen *display;
 	//! instance of \ref settings
-	settings *current_settings;
+	Settings *settings;
 	//! instance of \ref autosuspend
 	autosuspend *autoSuspend;
 	//! instance of \ref suspendDialog
 	suspendDialog *suspendDlg;
 
+	//! pointer to class HardwareInfo object
+	HardwareInfo *hwinfo;
+	
+	//! struct wth information about suspend states and permissions
+	SuspendStates suspend;
+	//! enum with the last called suspend, this need to be reset if needed
+	int calledSuspend;
+
 	//! instance of \ref detaileddialog 
 	detaileddialog *detailedDlg;
 
@@ -151,14 +156,6 @@ private:
 	* \li false: if not
 	*/
 	bool hal_error_shown;
-	//! represent if change the brightness is supported
-	/*!
-	* This boolean tells if the machine support brightness interface
-	* \li true:  if supported
-	* \li false: if not
-	*/
-	bool brightness_supported;
-	
 
 	//! a menu entry ID
 	/*! contains the ID of the menuentry for kpowersave configure Dialog */
@@ -281,7 +278,7 @@ private:
 	//! draw all icon related things for \ref redrawPixmap()
 	void drawIcon();
 	//! to intialise the menu for the kickerapplet
-        void init_menu();
+        void initMenu();
 	//! load the icon for \ref redrawPixmap()
 	void loadIcon();
 	//! draw/redraw the icon for the kickerapplet
@@ -292,8 +289,6 @@ private:
 	QString translateProgressMsg( QString );
 	//! to update the Tooltip of the kickerapplet
 	void updateTooltip();
-	//! to update the menu with the cpu frequency within the main menu
-	void updateCPUFreqMenu();
 
 	//! Eventhandler to catch mouse-press-events and react 
 	void mousePressEvent( QMouseEvent *qme );
@@ -302,26 +297,29 @@ private:
 	//! Eventhandler to catch mouse enter events and react
 	void enterEvent( QEvent *qee);
 
+	//! to handle mount/umount on resume/suspend
+	bool handleMounts ( bool suspend );
+
 private slots:
 
-	//! send command for stand-by to the powersave daemon
+	//! send command for stand-by to the HAL daemon
 	bool do_standby();
-	//! send command for suspend_to_disk to the powersave daemon
+	//! send command for suspend_to_disk to the HAL daemon
 	bool do_suspend2disk();
-	//! send command for suspend_to_RAM to the powersave daemon
+	//! send command for suspend_to_RAM to the HAL daemon
 	bool do_suspend2ram();
 	
 	//! send command for autosuspend called if signal \ref inactivity::inactivityTimeExpired() recieved
 	bool do_autosuspend();
 	//! starts the Yast2-power-management module
 	void do_config();
-	//! sets the new scheme to the powersave daemon
+	//! sets the new scheme with all settings
 	void do_setActiveScheme( int );
 	//! called if icon background must be changed
 	void do_setIconBG();
 	//! to set the autosuspend on/off over the menu
 	void do_setAutosuspend();
-	//! sets the speedpolicy in the powersave daemon
+	//! sets the CPU Freq policy via the HAL daemon
 	void do_setSpeedPolicy( int );
 	//! called if there are problems with starting yast module
 	void slotConfigProcessExited( KProcess * );
@@ -332,62 +330,69 @@ private slots:
 	//! called to open website to report bugs
 	void slotReportBug();
 	//! called if the configure dialog is destroyed
-	void observe_configDlg();
+	void observeConfigDlg();
 	//! called if user exit from kpowersave
 	void _quit();
+
 	//! to update the main menu of the kickerapplet
 	/*! this is bound to generalDataChanged singal in pdaemon */
 	void update();
 	//! to update the scheme-menu within the main menu
 	void updateSchemeMenu();
-	
-	//! this is invoked if the powersave daemon wants to show some message to the user
-	void showClientMessage( QString );
+	//! to update the menu with the cpu frequency within the main menu
+	void updateCPUFreqMenu();
 
         //! this set \ref suspendType from signal
-        void set_suspend_type( QString );
+        void setSuspendType( QString suspendtype );
 	//! this set the autosuspend and start the monitoring
 	void setAutoSuspend( bool );
 
-	//! this lock the screen if a lidclosed() signal is triggered
-	void lockscreen_on_lidcloseEvent();
-	//! this lock the screen if a lockscreen() signal is triggered
-	void lockscreen_on_lockEvent();
-	//! this handle the lidopen event if lidopen() signal is triggered
-	void handleLidOpenEvent();
+	//! called for critical battery event SHUTDOWN
+	void handleCriticalBatteryActionCall();
+	//! set for a battery status the related actions
+	void handleActionCall ( action action, int value, bool checkAC = false );
+
+	//! this lock/reactivate the screen if a lidcloseStatus() signal is triggered
+	void handleLidEvent( bool closed );
 	//! show the login dialog after locked the screen
 	void activateLoginScreen();
-	
+
+	//! handle event for press power button and call action
+	void handlePowerButtonEvent();
+	//!  handle event for press s2ram/sleep button and call action
+	void handleSleepButtonEvent();
+	//!  handle event for press s2disk button and call action
+	void handleS2DiskButtonEvent();
+
 	//! to show the kpowersave configure_dialog
-	void show_configure_dialog();
+	void showConfigureDialog();
 	//! to show the KNotify config dialog
-	void show_configure_notifications_dialog();
+	void showConfigureNotificationsDialog();
 	
 	//! this is invoked if the powersave daemon wants to show a progress dialog
 	void showProgressDialog( QString );
-	//void showProgressDialog( QString, int);
 	//! this is called if the progress dialog is closed by user
 	void closeProgressDialog();
 
 	//! this emit the KNotify event for a battery warning state state
-	void notifyBatteryStatusChange ( QString );
+	void notifyBatteryStatusChange ( int type, int state );
 	//! this emit the KNotify event for change AC status
-	void notifyACStatusChange ( bool );
+	void handleACStatusChange ( bool );
 	//! this emit the KNotify event if the machine go to autosuspend
 	void notifyAutosuspend();
 	//! this emit the KNotify events if scheme switched
 	void notifySchemeSwitch();
 	//! this emit the KNotify events if the machine go to suspend/Standby
-	void notifySuspend( QString );
+	void notifySuspend( int );
 	//! this emit the KNotify events if the machine resumed
-	void notifyResume( QString );
+	void handleResumeSignal( int result );
 
 	//! to display HAL error msg
-	void showHalErrorMsg();
+	void showHalErrorMsg( );
 	//! this is invoked to display powersave error message
-	void showPowersaveErrorMsg();
-	//! to display DBUS related error messages
 	void showDBusErrorMsg( int );
+	//! this show a blocking dialog from kpowersave with the given message
+	void showErrorMessage( QString msg );
 
 	//! this is called when detailed dialog is closed
 	void closedetaileddialog();
@@ -400,8 +405,8 @@ public:
 	virtual ~kpowersave();
 	
 k_dcop:	
-	//! dcop function to call lockscreen_on_lockEvent()
-	bool lock_screen();
+	//! dcop function to lock the screen
+	bool lockScreen();
 	//! dcop function to set a scheme 
 	bool do_setScheme( QString );
 	//! dcop function to set CPU Freq policy 
@@ -420,6 +425,9 @@ k_dcop:
 	//! dcop function to show the detailed dialog
 	void showDetailedDialog();
 
+        //! dcop function to find out if kpowersave manages DPMS
+        bool currentSchemeManagesDPMS();
+
 	//! dcop function to return the name of the current scheme 
 	QString currentScheme ();
 	//! dcop function to return the current cpufreqpolicy
@@ -428,9 +436,9 @@ k_dcop:
 	//! dcop function to return the supported sleeping states
 	QStringList allowed_sleepingStates();
 	//! dcop function to return the schemes
-	QStringList list_schemes();
+	QStringList listSchemes();
 	//! dcop function to return the supported CPU 
-	QStringList list_CPUFreqPolicies();
+	QStringList listCPUFreqPolicies();
 };
 
 #endif // _KPOWERSAVE_H_
