@@ -3,9 +3,8 @@
 *                         <dkukawka@suse.de>, <danny.kukawka@web.de>      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
+*   it under the terms of version 2 of the GNU General Public License     *
+*   as published by the Free Software Foundation.                         *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -52,7 +51,7 @@
 *  \class 	screen
 *  \brief 	class for all screensaver related funtionality
 *  \author 	Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
-*  \date    	2004
+*  \date    	2004 - 2006
 */
 class screen : public QWidget
 {
@@ -144,6 +143,8 @@ public:
 	
 	//! blank only the screen
 	void blankOnlyScreen( bool );
+	//! reset KDE screensaver settings
+	bool resetKDEScreensaver();
 	//! force DPMS off for display
 	void forceDPMSOff();
 
